@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -83,7 +83,7 @@ iarrow_generate_caption_sub( iImage *iimage, iArrow *iarrow, gboolean *first )
 static const char *
 iarrow_generate_caption( iObject *iobject )
 {
-	static const char *names_current[] = {
+	static const char *names[] = {
 		CLASS_HGUIDE,
 		CLASS_VGUIDE,
 		CLASS_MARK,
@@ -91,22 +91,11 @@ iarrow_generate_caption( iObject *iobject )
 		NULL
 	};
 
-	/* 7.8 used slightly different names :-(
-	 */
-	static const char *names_compatibility[] = {
-		CLASS_HGUIDE,
-		CLASS_VGUIDE,
-		CLASS_POINT,
-		CLASS_ARROW,
-		NULL
-	};
-
 	iArrow *iarrow = IARROW( iobject );
 	VipsBuf *buf = &iarrow->caption_buffer;
 	const int nimages = g_slist_length( CLASSMODEL( iarrow )->iimages );
 	Expr *expr;
 	gboolean result;
-	const char **names;
 	gboolean first;
 	int i;
 
@@ -116,11 +105,6 @@ iarrow_generate_caption( iObject *iobject )
 		!result )
 		return( _( "No image" ) );
 
-	if( HEAPMODEL( iarrow )->row->ws->compat_78 ) 
-		names = names_compatibility;
-	else
-		names = names_current;
-
 	vips_buf_rewind( buf );
 	heapmodel_name( HEAPMODEL( iarrow ), buf );
 	vips_buf_appendf( buf, " " );
