@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -112,7 +112,7 @@ iimageview_drag_data_get( GtkWidget *widget, GdkDragContext *context,
 
 		/* Drag the fully-qualified row name.
 		 */
-		row_qualified_name_relative( main_workspacegroup->sym, 
+		row_qualified_name_relative( main_workspaceroot->sym, 
 			row, &buf );
 		gtk_selection_data_set( selection_data,
 			gdk_atom_intern( "text/symbol", FALSE ), 8, 
@@ -146,7 +146,7 @@ iimageview_drag_data_received( GtkWidget *widget, GdkDragContext *context,
 
 		/* Block drags to ourselves ... pointless.
 		 */
-		if( (from_row = row_parse_name( main_workspacegroup->sym,
+		if( (from_row = row_parse_name( main_workspaceroot->sym,
 			from_row_path )) && 
 			from_row != row ) {
 			iText *itext = ITEXT( HEAPMODEL( iimage )->rhs->itext );
@@ -156,15 +156,15 @@ iimageview_drag_data_received( GtkWidget *widget, GdkDragContext *context,
 			/* Qualify relative to us. We don't want to embed
 			 * workspace names unless we have to.
 			 */
-			row_qualified_name_relative( row->top_row->sym, 
-				from_row, &buf );
+			if( row->top_row->sym ) 
+				row_qualified_name_relative( row->top_row->sym, 
+					from_row, &buf );
 
 			if( itext_set_formula( itext, vips_buf_all( &buf ) ) ) {
 				itext_set_edited( itext, TRUE );
 				(void) expr_dirty( row->expr, 
 					link_serial_new() );
-				filemodel_set_modified( FILEMODEL( row->ws ), 
-					TRUE );
+				workspace_set_modified( row->ws, TRUE );
 				symbol_recalculate_all();
 			}
 
@@ -194,16 +194,20 @@ static void
 iimageview_link( View *view, Model *model, View *parent )
 {
 	iImageview *iimageview = IIMAGEVIEW( view );
-	Rowview *rview = ROWVIEW( parent->parent );
-	Row *row = ROW( VOBJECT( rview )->iobject );
+
+	Rowview *rview;
 
 	VIEW_CLASS( parent_class )->link( view, model, parent );
 
-	rowview_menu_attach( rview, GTK_WIDGET( iimageview->id ) );
+	if( (rview = ROWVIEW( parent->parent )) ) { 
+		Row *row = ROW( VOBJECT( rview )->iobject );
 
-	if( row->popup && row->top_row == row ) {
-		row->popup = FALSE;
-		iimageview_edit( GTK_WIDGET( view ), iimageview );
+		rowview_menu_attach( rview, GTK_WIDGET( iimageview->id ) );
+
+		if( row->popup && row->top_row == row ) {
+			row->popup = FALSE;
+			iimageview_edit( GTK_WIDGET( view ), iimageview );
+		}
 	}
 }
 
@@ -285,18 +289,18 @@ iimageview_class_init( iImageviewClass *class )
 }
 
 static void 
-iimageview_doubleclick_one_cb( GtkWidget *widget, 
-	iImageview *iimageview, int state )
+iimageview_doubleclick_one_cb( GtkWidget *widget, GdkEvent *event, 
+	iImageview *iimageview )
 {
 	Heapmodel *heapmodel = HEAPMODEL( VOBJECT( iimageview )->iobject );
 	Row *row = heapmodel->row;
 
-	row_select_modifier( row, state );
+	row_select_modifier( row, event->button.state );
 }
 
 static void 
-iimageview_doubleclick_two_cb( GtkWidget *widget, 
-	iImageview *iimageview, int state )
+iimageview_doubleclick_two_cb( GtkWidget *widget, GdkEvent *event, 
+	iImageview *iimageview )
 {
 	iimageview_edit( widget, iimageview );
 }
@@ -359,7 +363,7 @@ iimageview_init( iImageview *iimageview )
 	/* Need these events in the enclosing workspaceview.
 	 */
 	gtk_widget_add_events( GTK_WIDGET( iimageview->id ), 
-		GDK_BUTTON_MOTION_MASK | 
+		GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK |
 		GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK ); 
 
 	iimageview->label = gtk_label_new( "" );
