@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
  */
 
@@ -238,11 +238,16 @@ itext_decompile_element( VipsBuf *buf, PElement *base, gboolean top )
 			vips_buf_appends( buf, ")" );
 	}
 	else if( PEISMANAGED( base ) ) {
-		Managed *managed = PEGETMANAGED( base );
+		Managed *managed;
 
-		vips_buf_appendf( buf, "<%s ", G_OBJECT_TYPE_NAME( managed ) );
-		iobject_info( IOBJECT( managed ), buf );
-		vips_buf_appends( buf, ">" );
+		if( !(managed = PEGETMANAGED( base )) ) 
+			vips_buf_appendf( buf, "<NULL managed>" );  
+		else { 
+			vips_buf_appendf( buf, "<%s ", 
+				G_OBJECT_TYPE_NAME( managed ) );
+			iobject_info( IOBJECT( managed ), buf );
+			vips_buf_appends( buf, ">" );
+		}
 	}
 	else if( PEISCLASS( base ) ) {
 		Compile *compile = PEGETCLASSCOMPILE( base );
@@ -555,7 +560,8 @@ itext_update_model( Heapmodel *heapmodel )
 #ifdef DEBUG
 	printf( "itext_update_model: " );
 	row_name_print( row );
-	if( row->sym && row->sym->dirty )
+	if( row->sym && 
+		row->sym->dirty )
 		printf( " (dirty)" );
 	printf( "\n" );
 #endif /*DEBUG*/
@@ -631,7 +637,8 @@ itext_update_heap( Heapmodel *heapmodel )
 		VipsBuf buf = VIPS_BUF_STATIC( txt );
 		ParseRhsSyntax syntax;
 
-		if( is_super( row->sym ) ) {
+		if( row->sym &&
+			is_super( row->sym ) ) {
 			/* A super member ... special syntax.
 			 */
 			vips_buf_appendf( &buf, "%s", itext->formula );
